#[repr(u8)]pub enum MarkingType {
Atomic = 0,
Incremental = 1,
IncrementalAndConcurrent = 2,
}Expand description
Specifies supported marking types.
Variants
Atomic = 0
Atomic stop-the-world marking. This option does not require any write barriers but is the most intrusive in terms of jank.
Incremental = 1
Incremental marking interleaves marking with the rest of the application workload on the same thread.
IncrementalAndConcurrent = 2
Incremental and concurrent marking.