#[repr(u8)]pub enum SweepingType {
Atomic = 0,
Incremental = 1,
IncrementalAndConcurrent = 2,
}Expand description
Specifies supported sweeping types.
Variants
Atomic = 0
Atomic stop-the-world sweeping. All of sweeping is performed at once.
Incremental = 1
Incremental sweeping interleaves sweeping with the rest of the application workload on the same thread.
IncrementalAndConcurrent = 2
Incremental and concurrent sweeping. Sweeping is split and interleaved with the rest of the application.