GcCell

Struct GcCell 

pub struct GcCell<T> { /* private fields */ }
GcCell is a zero-overhead memory cell that provides interior mutability for garbage collected types.

Mutable access to the value inside the GcCell is granted by delivering proof that the caller has mutable access to the V8 Isolate (such as through a HandleScope). This statically guarantees that access patterns follow the rules of both the garbage collector and the Rust borrow checker.

GcCell also implements Traced, which means that it can hold other garbage collected references, like Member or WeakMember. If the GcCell holds other garbage collected objects, those objects cannot be accessed while the GcCell is borrowed, and the caller must construct temporary pointers (UnsafePtr<T>) on the stack in order to access nested objects in the object graph.

Implementations

Source

impl<T> GcCell<T>

pub fn new(value: T) -> Self

pub fn set(&self, isolate: &mut Isolate, value: T)

Source

impl<T> GcCell<T>

pub fn get<'a>(&'a self, isolate: &'a Isolate) -> &'a T

pub fn get_mut<'a>(&'a self, isolate: &'a mut Isolate) -> &'a mut T

pub fn with<'a, 's, R>( &'a self, scope: &'a mut HandleScope<'s>, f: impl FnOnce(&'a mut HandleScope<'s>, &'a mut T) -> R, ) -> R