pub struct HeapCreateParams {
pub marking_support: MarkingType,
pub sweeping_support: SweepingType,
}Fields
marking_support: MarkingTypeSpecifies which kind of marking are supported by the heap.
sweeping_support: SweepingTypeSpecifies which kind of sweeping are supported by the heap.