UnsafePtr

Struct UnsafePtr 

pub struct UnsafePtr<T: GarbageCollected> { /* private fields */ }
UnsafePtr is used to refer to an on-heap object from the stack.

Implementations

Source

impl<T: GarbageCollected> UnsafePtr<T>

pub unsafe fn new(value: &impl GetRustObj<T>) -> Option<UnsafePtr<T>>

Create a new UnsafePtr.

Safety

The caller must ensure that the returned pointer is always stored on the stack, or is safely moved into one of the other cppgc pointer types.

pub unsafe fn as_ref(&self) -> &T