WeakPersistent

Struct WeakPersistent 

pub struct WeakPersistent<T: GarbageCollected> { /* private fields */ }
WeakPersistent is a way to create a weak pointer from an off-heap object to an on-heap object. The pointer is automatically cleared when the pointee gets collected. WeakPersistent must be constructed and destructed in the same thread.

Implementations

Source

impl<T: GarbageCollected> WeakPersistent<T>

pub fn empty() -> Self

Create a new empty WeakPersistent which may be set later.

pub fn new(other: &impl GetRustObj<T>) -> Self

Create a new WeakPersistent and initialize it with an object.

pub fn set(&mut self, other: &impl GetRustObj<T>)

Set the object pointed to by this WeakPersistent .

pub fn get(&self) -> Option<&T>

Borrow the object pointed to by this WeakPersistent .