pub trait Traced {
// Required method
fn trace(&self, visitor: &mut Visitor);
}Expand description
Trait for inlined objects that are not allocated themselves but otherwise follow managed heap layout.
pub trait Traced {
// Required method
fn trace(&self, visitor: &mut Visitor);
}Trait for inlined objects that are not allocated themselves but otherwise follow managed heap layout.