FrontendChannelImpl

Trait FrontendChannelImpl 

pub trait FrontendChannelImpl {
    // Required methods
    fn send_protocol_response(&mut self, call_id: i32, message: Serializable);
    fn send_protocol_notification(&mut self, message: Serializable);
    fn fall_through(&mut self, call_id: i32, method: &[u8], message: &[u8]);
    fn flush_protocol_notifications(&mut self);
}
Trait for sending protocol responses and notifications to clients.

Required Methods

fn send_protocol_response(&mut self, call_id: i32, message: Serializable)

Send a response to a protocol request.

fn send_protocol_notification(&mut self, message: Serializable)

Send a notification (no call_id).

fn fall_through(&mut self, call_id: i32, method: &[u8], message: &[u8])

Indicate that the message should be handled by another layer.

fn flush_protocol_notifications(&mut self)

Flush any queued notifications.

Implementors