new_custom_platform

Function new_custom_platform 

pub fn new_custom_platform(
    thread_pool_size: u32,
    idle_task_support: bool,
    unprotected: bool,
    platform_impl: impl PlatformImpl + 'static,
) -> UniqueRef<Platform>
Creates a custom platform backed by DefaultPlatform that delegates virtual method overrides to the provided PlatformImpl trait object.

This follows the same pattern as V8InspectorClient::new.

When unprotected is true, thread-isolated allocations are disabled (same as new_unprotected_default_platform). This is required when isolates may be created on threads other than the one that called V8::initialize.