Struct v8::script_compiler::Source
source · [−]#[repr(C)]pub struct Source(_);Expand description
Source code which can then be compiled to a UnboundScript or Script.
#[repr(C)]pub struct Source(_);Source code which can then be compiled to a UnboundScript or Script.