pub struct ModuleCachingInterface(/* private fields */);Implementations
Sourceimpl ModuleCachingInterface
impl ModuleCachingInterface
Sourcepub fn get_wire_bytes(&self) -> &[u8] ⓘ
pub fn get_wire_bytes(&self) -> &[u8] ⓘ
Get the full wire bytes, to check against the cached version.
Sourcepub fn set_cached_compiled_module_bytes(&mut self, bytes: &[u8]) -> bool
pub fn set_cached_compiled_module_bytes(&mut self, bytes: &[u8]) -> bool
Pass serialized (cached) compiled module bytes, to be deserialized and used as the result of this streaming compilation. The passed bytes will only be accessed inside this callback, i.e. lifetime can end after the call. The return value indicates whether V8 could use the passed bytes; {false} would be returned on e.g. version mismatch. This method can only be called once.