UnenteredIsolate

Struct UnenteredIsolate 

pub struct UnenteredIsolate { /* private fields */ }
An isolate that must be accessed via Locker.

Unlike OwnedIsolate, this isolate does not automatically enter itself upon creation. Instead, you must use a Locker to access it:

let mut isolate = v8::Isolate::new_unentered(Default::default());

// Access the isolate through a Locker
{
    let mut locker = v8::Locker::new(&mut isolate);
    let scope = &mut v8::HandleScope::new(&mut *locker);
    // ... use scope ...
}

// The locker is dropped, isolate can be used from another thread

Thread Safety

UnenteredIsolate implements Send, meaning it can be transferred between threads. However, V8 isolates are not thread-safe by themselves. You must:

  1. Only access the isolate through a Locker
  2. Never have multiple Lockers for the same isolate simultaneously (V8 will block if you try)

Dropping

When dropped, the isolate will be properly disposed. The drop will panic if a Locker is currently held for this isolate.

Implementations

Source

impl UnenteredIsolate

pub fn as_raw(&self) -> *mut RealIsolate

Returns the raw pointer to the underlying V8 isolate.

Safety

The returned pointer is only valid while this UnenteredIsolate exists and should only be used while a Locker is held.