pub unsafe fn shutdown_process()
Must be called after destroying the last used heap. Some process-global metadata may not be returned and reused upon a subsequent initialize_process() call.
initialize_process()