pub struct Member<T: GarbageCollected> { /* private fields */ }Expand description
Members are used in classes to contain strong pointers to other garbage collected objects. All Member fields of a class must be traced in the class’ trace method.
Implementations
Sourceimpl<T: GarbageCollected> Member<T>
impl<T: GarbageCollected> Member<T>
Sourcepub fn new(other: &impl GetRustObj<T>) -> Self
pub fn new(other: &impl GetRustObj<T>) -> Self
Create a new Member and initialize it with an object.
Sourcepub unsafe fn get(&self) -> Option<&T>
pub unsafe fn get(&self) -> Option<&T>
Get the object pointed to by this
Member
, returning None if the pointer is empty or has been garbage-collected.
Safety
The caller must ensure that this pointer is being traced correctly by appearing in the trace
implementation of the object that owns the pointer. Between initializing the pointer and calling get(), the pointer must be reachable by the garbage collector.