Persistent

Struct Persistent 

pub struct Persistent<T: GarbageCollected> { /* private fields */ }
Persistent is a way to create a strong pointer from an off-heap object to another on-heap object. As long as the Persistent handle is alive the GC will keep the object pointed to alive. The Persistent handle is always a GC root from the point of view of the GC. Persistent must be constructed and destructed in the same thread.

Implementations

Source

impl<T: GarbageCollected> Persistent<T>

pub fn empty() -> Self

Create a new empty Persistent which may be set later.

pub fn new(other: &impl GetRustObj<T>) -> Self

Create a new Persistent and initialize it with an object.

pub fn set(&mut self, other: &impl GetRustObj<T>)

Set the object pointed to by this Persistent .

pub fn get(&self) -> Option<&T>

Borrow the object pointed to by this Persistent .