pub struct WeakPersistent<T: GarbageCollected> { /* private fields */ }Expand description
WeakPersistent is a way to create a weak pointer from an off-heap object to an on-heap object. The pointer is automatically cleared when the pointee gets collected. WeakPersistent must be constructed and destructed in the same thread.
Implementations
Sourceimpl<T: GarbageCollected> WeakPersistent<T>
impl<T: GarbageCollected> WeakPersistent<T>