pub trait FrontendChannelImpl {
// Required methods
fn send_protocol_response(&mut self, call_id: i32, message: Serializable);
fn send_protocol_notification(&mut self, message: Serializable);
fn fall_through(&mut self, call_id: i32, method: &[u8], message: &[u8]);
fn flush_protocol_notifications(&mut self);
}Expand description
Trait for sending protocol responses and notifications to clients.
Required Methods
Sourcefn send_protocol_response(&mut self, call_id: i32, message: Serializable)
fn send_protocol_response(&mut self, call_id: i32, message: Serializable)
Send a response to a protocol request.
Sourcefn send_protocol_notification(&mut self, message: Serializable)
fn send_protocol_notification(&mut self, message: Serializable)
Send a notification (no call_id).
Sourcefn fall_through(&mut self, call_id: i32, method: &[u8], message: &[u8])
fn fall_through(&mut self, call_id: i32, method: &[u8], message: &[u8])
Indicate that the message should be handled by another layer.
Sourcefn flush_protocol_notifications(&mut self)
fn flush_protocol_notifications(&mut self)
Flush any queued notifications.