pub struct UnenteredIsolate { /* private fields */ }Expand description
An isolate that must be accessed via Locker.
Unlike OwnedIsolate, this isolate does not automatically enter itself
upon creation. Instead, you must use a Locker to access it:
ⓘ
let mut isolate = v8::Isolate::new_unentered(Default::default());
// Access the isolate through a Locker
{
let mut locker = v8::Locker::new(&mut isolate);
let scope = &mut v8::HandleScope::new(&mut *locker);
// ... use scope ...
}
// The locker is dropped, isolate can be used from another threadThread Safety
UnenteredIsolate implements Send, meaning it can be transferred between
threads. However, V8 isolates are not thread-safe by themselves. You must:
- Only access the isolate through a
Locker - Never have multiple
Lockers for the same isolate simultaneously (V8 will block if you try)
Dropping
When dropped, the isolate will be properly disposed. The drop will panic
if a Locker is currently held for this isolate.
Implementations